=================
Grok Glossary
=================

* **adapter** - 
  Bla bla

* **(Grok) application** - 
  Bla bla
  
* **buildout** -
  Bla bla

* **buildout egg** -
  Bla bla

* **(Grok) container** - 
  Bla bla

* **(Grok) directive** - 
  Bla bla

* **directory resource** - 
  Bla bla

* **egg** - 
  Bla bla

* **global utility** - 
  Bla bla

* **grokproject** - 
  A command line tool for creating a Grok project using buildout.

* **layer** -
  Bla bla

* **local utility** -
  Bla bla

* **martian** - 
  Bla bla

* **megrok** =
  Bla bla

* **(Grok) model** - 
  Bla bla

* **Python Cheeseshop** -
  Bla bla

* **(Grok) site** - 
  Bla bla

* **skin** - 
  Bla bla

* **(Grok) view** - 
  Bla bla  

* **viewlet** - 
  Bla bla

* **viewlet manager** - 
  Bla bla

* **zc.buildout** - see buildout

* **zc.resourcelibrary** - 
  Bla bla

* **ZCML** - 
  Bla bla

* **ZODB** - 
  Bla bla

* **ZPT** -
  Zope Page Template


